pub struct ExtensionPointPolicy { /* private fields */ }Implementations
Sourceimpl ExtensionPointPolicy
impl ExtensionPointPolicy
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new ExtensionPointPolicy with default settings.
The default policy has all flags set to false.
Sourcepub fn build(self) -> Result<(), Error>
pub fn build(self) -> Result<(), Error>
Builds the policy and applies it to the current process.
Errors
Returns an error if the policy could not be set.
Sourcepub fn set_disable_extension_points(&mut self, status: bool) -> &mut Self
pub fn set_disable_extension_points(&mut self, status: bool) -> &mut Self
Corresponds to the DisableExtensionPoints flag.
Sourcepub unsafe fn custom_set(&mut self, flag: u32, status: bool) -> &mut Self
pub unsafe fn custom_set(&mut self, flag: u32, status: bool) -> &mut Self
Sets a custom flag in the policy.
Safety
This function is unsafe because it allows arbitrary modification of the policy flags.